@@ -1,7 +1,7 @@
 package Tkx;
 
 use strict;
-our $VERSION = '1.10_03';
+our $VERSION = '1.08';
 
 {
     # predeclare
@@ -224,10 +224,6 @@ BEGIN {
     $interp->Init;
 }
 
-sub interp {
-    return $interp;
-}
-
 sub expand_name {
     my(@f) = (shift);
     @f = split(/(?<!_)_(?!_)/, $f[0]) if wantarray;
@@ -335,7 +331,7 @@ sub call {
            my $i = 1;
            my($pkg, $file, $line);
            while (($pkg, $file, $line) = caller($i)) {
-               last if $pkg !~ m/^Tkx(::|$)/;
+               last if $pkg !~ /^Tkx(::|$)/;
                $i++;
            };
            $@ .= " at $file line $line.\n";
@@ -379,7 +375,7 @@ the Tcl/Tk documentation with no surprises added by the Perl layer.
 
 This is the "reference manual" for Tkx. For a gentle introduction please
 read the L<Tkx::Tutorial>.  The tutorial at
-L<http://www.tkdocs.com/tutorial/> is also strongly recommended.
+L<http://www.tkdocs.com/tutorial/> is also strongly recommened.
 
 =head2 Functions
 
@@ -389,7 +385,7 @@ The following functions are provided:
 
 =item Tkx::AUTOLOAD( @args )
 
-All calls into the C<< Tkx:: >> namespace not explicitly listed here are trapped
+All calls into the C<< Tkx:: >> namespace not explictly listed here are trapped
 by Perl's AUTOLOAD mechanism and turned into a call of the corresponding Tcl or
 Tk command.  The Tcl string result is returned as a single value in both scalar
 and list context.  Tcl errors are propagated as Perl exceptions.
@@ -408,7 +404,7 @@ Commands"> below.
 Don't call Tkx::AUTOLOAD() directly yourself.
 
 The available Tcl commands are documented at
-L<http://www.tcl.tk/man/tcl/TclCmd/contents.htm>.  The available Tk commands are
+L<http://www.tcl.tk/man/tcl/TclCmd/contents.htm>.  The availale Tk commands are
 documented at L<http://www.tcl.tk/man/tcl/TkCmd/contents.htm>.
 
 =item Tkx::Ev( $field, ... )
@@ -453,7 +449,7 @@ let Tcl do the globbing for you.  The example above is purely educational.
 
 The Tkx::list() function would invoke the Tcl command that does the reverse
 operation -- creating a list from the arguments passed in. You seldom need to
-call Tkx::list() explicitly as arrays are automatically converted to Tcl lists
+call Tkx::list() explictly as arrays are automatically converted to Tcl lists
 when passed as arguments to Tcl commands.
 
 =back
@@ -507,18 +503,18 @@ these as described in L</"Widget handles"> below.
 =head3 Passing arguments
 
 The arguments passed to Tcl can be plain scalars, array references, code
-references, scalar references, or hash references.
+references, or scalar references.
 
 Plain scalars (strings and numbers) as just passed on unchanged to Tcl.
 
-Array references, where the first element is not a code reference, are converted into Tcl
+Arrays, where the first element is not a code reference, are converted into Tcl
 lists and passed on.  The arrays can contain strings, numbers, and/or array
 references to form nested lists.
 
 Code references, and arrays where the first element is a code reference, are
 converted into special Tcl command names in the "::perl" Tcl namespace that
 will call back into the corresponding Perl function when invoked from Tcl.  See
-L</"Callbacks to Perl"> for a description how this is used.
+L</"Callbacks to Perl"> for a description how how this is used.
 
 Scalar references are converted into special Tcl variables in the "::perl" Tcl
 namespace that is tied to the corresponding variable on the Perl side.
@@ -526,11 +522,6 @@ Any changes to the variable on the Perl side will be reflected in the value
 on the Tcl side.  Any changes to the variable on the Tcl side will be reflected
 in the value on the Perl side.
 
-Hash references are converted into special Tcl array variables in the "::perl" Tcl
-namespace that is tied to the corresponding hash on the Perl side.  Any changes to
-the hash on the Perl side will be reflected in the array on the Tcl side. Any
-changes to the array on the Tcl side will be reflected in the hash on the Perl side.
-
 Anything else will just be converted to strings using the Perl rules for
 stringification and passed on to Tcl.
 
